MethodChannelFlutterMidiPro class
An implementation of FlutterMidiProPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterMidiProPlatform
- MethodChannelFlutterMidiPro
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
channelPressure(
int sfId, int channel, int value) → Future< void> -
override
-
configureAudioSession(
String category, bool mixWithOthers, bool duckOthers) → Future< void> -
override
-
controlChange(
int sfId, int channel, int controller, int value) → Future< void> -
Sends a MIDI Control Change (CC) message to the specified channel on a soundfont.
controlleris the CC number (0-127),valueis the CC value (0-127).override -
dispose(
) → Future< void> -
override
-
getMidiPlayerState(
) → Future< List< int> > -
override
-
init(
int sampleRate, int bufferSize, int polyphony) → Future< void> -
override
-
keyPressure(
int sfId, int channel, int key, int value) → Future< void> -
override
-
loadMidiData(
Uint8List data, int sfId) → Future< void> -
override
-
loadMidiFile(
String path, int sfId) → Future< void> -
override
-
loadSoundfont(
String path, int bank, int program) → Future< int> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
panic(
) → Future< void> -
override
-
pauseMidi(
) → Future< void> -
override
-
pitchBend(
int sfId, int channel, int value) → Future< void> -
override
-
playMidi(
) → Future< void> -
override
-
playNote(
int channel, int key, int velocity, int sfId) → Future< void> -
override
-
seekMidi(
int tick) → Future< void> -
override
-
selectInstrument(
int sfId, int channel, int bank, int program) → Future< void> -
override
-
sendMidiEvent(
int sfId, int status, int data1, int data2) → Future< void> -
override
-
setChorus(
bool enabled, int voiceCount, double level, double speed, double depth) → Future< void> -
override
-
setDelay(
bool enabled, double time, double feedback, double lowPassCutoff, double wetDryMix) → Future< void> -
override
-
setDistortion(
bool enabled, int preset, double preGain, double wetDryMix) → Future< void> -
override
-
setEqualizer(
bool enabled, double bassGain, double midGain, double trebleGain) → Future< void> -
override
-
setMasterGain(
double gain) → Future< void> -
override
-
setMidiLoop(
int count) → Future< void> -
override
-
setMidiTempo(
double factor) → Future< void> -
override
-
setPitchBendRange(
int sfId, int channel, int semitones) → Future< void> -
override
-
setReverb(
bool enabled, double roomSize, double damping, double width, double level) → Future< void> -
override
-
stopAllNotes(
int sfId) → Future< void> -
override
-
stopMidi(
) → Future< void> -
override
-
stopNote(
int channel, int key, int sfId) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unloadSoundfont(
int sfId) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited